"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBasicMessagesByConnectionId = exports.useProofByState = exports.useProofById = exports.useProofs = exports.useCredentialByState = exports.useCredentialById = exports.useCredentials = exports.useConnectionByState = exports.useConnectionById = exports.useConnections = exports.useAgent = void 0;
const core_1 = require("@aries-framework/core");
const React = __importStar(require("react"));
const react_1 = require("react");
const AgentContext = (0, react_1.createContext)(undefined);
const ConnectionContext = (0, react_1.createContext)(undefined);
const CredentialContext = (0, react_1.createContext)(undefined);
const ProofContext = (0, react_1.createContext)(undefined);
const BasicMessageContext = (0, react_1.createContext)(undefined);
// Agent
const useAgent = () => {
    const agentContext = (0, react_1.useContext)(AgentContext);
    if (!agentContext) {
        throw new Error('useAgent must be used within a AgentContextProvider');
    }
    return agentContext;
};
exports.useAgent = useAgent;
// Connection
const useConnections = () => {
    const connectionContext = (0, react_1.useContext)(ConnectionContext);
    if (!connectionContext) {
        throw new Error('useConnections must be used within a ConnectionContextProvider');
    }
    return connectionContext;
};
exports.useConnections = useConnections;
const useConnectionById = (id) => {
    const { connections } = (0, exports.useConnections)();
    return connections.find((c) => c.id === id);
};
exports.useConnectionById = useConnectionById;
const useConnectionByState = (state) => {
    const { connections } = (0, exports.useConnections)();
    return connections.filter((c) => c.state === state);
};
exports.useConnectionByState = useConnectionByState;
// Credential
const useCredentials = () => {
    const credentialContext = (0, react_1.useContext)(CredentialContext);
    if (!credentialContext) {
        throw new Error('useCredentials must be used within a CredentialContextProvider');
    }
    return credentialContext;
};
exports.useCredentials = useCredentials;
const useCredentialById = (id) => {
    const { credentials } = (0, exports.useCredentials)();
    return credentials.find((c) => c.id === id);
};
exports.useCredentialById = useCredentialById;
const useCredentialByState = (state) => {
    const { credentials } = (0, exports.useCredentials)();
    return credentials.filter((c) => c.state === state);
};
exports.useCredentialByState = useCredentialByState;
// Proofs
const useProofs = () => {
    const proofContext = (0, react_1.useContext)(ProofContext);
    if (!proofContext) {
        throw new Error('useProofs must be used within a ProofContextProvider');
    }
    return proofContext;
};
exports.useProofs = useProofs;
const useProofById = (id) => {
    const { proofs } = (0, exports.useProofs)();
    return proofs.find((p) => p.id === id);
};
exports.useProofById = useProofById;
const useProofByState = (state) => {
    const { proofs } = (0, exports.useProofs)();
    return proofs.filter((p) => p.state === state);
};
exports.useProofByState = useProofByState;
const useBasicMessages = () => {
    const basicMessageContext = (0, react_1.useContext)(BasicMessageContext);
    if (!basicMessageContext) {
        throw new Error('useBasicMessages must be used within a BasicMessageContextProvider');
    }
    return basicMessageContext;
};
// BasicMessages
const useBasicMessagesByConnectionId = (connectionId) => {
    const { basicMessages } = useBasicMessages();
    return basicMessages.filter((m) => m.connectionId === connectionId);
};
exports.useBasicMessagesByConnectionId = useBasicMessagesByConnectionId;
const AgentProvider = ({ agent, children }) => {
    const [agentState, setAgentState] = (0, react_1.useState)({
        loading: true,
        agent,
    });
    const [connectionState, setConnectionState] = (0, react_1.useState)({
        connections: [],
        loading: true,
    });
    const [credentialState, setCredentialState] = (0, react_1.useState)({
        credentials: [],
        loading: true,
    });
    const [proofState, setProofState] = (0, react_1.useState)({
        proofs: [],
        loading: true,
    });
    const [basicMessageState, setBasicMessageState] = (0, react_1.useState)({
        basicMessages: [],
        loading: true,
    });
    const setInitialState = async () => {
        if (agent) {
            const connections = await agent.connections.getAll();
            const credentials = await agent.credentials.getAll();
            const proofs = await agent.proofs.getAll();
            const basicMessages = await agent.basicMessages.findAllByQuery({});
            setAgentState({ agent, loading: false });
            setConnectionState({ connections, loading: false });
            setCredentialState({ credentials, loading: false });
            setProofState({ proofs, loading: false });
            setBasicMessageState({ basicMessages, loading: false });
        }
    };
    (0, react_1.useEffect)(() => {
        setInitialState();
    }, [agent]);
    (0, react_1.useEffect)(() => {
        if (!connectionState.loading) {
            const listener = (event) => {
                // We shouldn't modify react state directly
                const newConnectionsState = [...connectionState.connections];
                const index = newConnectionsState.findIndex((connection) => connection.id === event.payload.connectionRecord.id);
                if (index > -1) {
                    newConnectionsState[index] = event.payload.connectionRecord;
                }
                else {
                    newConnectionsState.unshift(event.payload.connectionRecord);
                }
                setConnectionState({
                    loading: connectionState.loading,
                    connections: newConnectionsState,
                });
            };
            agent === null || agent === void 0 ? void 0 : agent.events.on(core_1.ConnectionEventTypes.ConnectionStateChanged, listener);
            return () => {
                agent === null || agent === void 0 ? void 0 : agent.events.off(core_1.ConnectionEventTypes.ConnectionStateChanged, listener);
            };
        }
    }, [connectionState, agent]);
    (0, react_1.useEffect)(() => {
        if (!credentialState.loading) {
            const listener = async (event) => {
                const newCredentialsState = [...credentialState.credentials];
                const index = newCredentialsState.findIndex((credential) => credential.id === event.payload.credentialRecord.id);
                if (index > -1) {
                    newCredentialsState[index] = event.payload.credentialRecord;
                }
                else {
                    newCredentialsState.unshift(event.payload.credentialRecord);
                }
                setCredentialState({
                    loading: credentialState.loading,
                    credentials: newCredentialsState,
                });
            };
            agent === null || agent === void 0 ? void 0 : agent.events.on(core_1.CredentialEventTypes.CredentialStateChanged, listener);
            return () => {
                agent === null || agent === void 0 ? void 0 : agent.events.off(core_1.CredentialEventTypes.CredentialStateChanged, listener);
            };
        }
    }, [credentialState, agent]);
    (0, react_1.useEffect)(() => {
        if (!proofState.loading) {
            const listener = (event) => {
                const newProofsState = [...proofState.proofs];
                const index = newProofsState.findIndex((proof) => proof.id === event.payload.proofRecord.id);
                if (index > -1) {
                    newProofsState[index] = event.payload.proofRecord;
                }
                else {
                    newProofsState.unshift(event.payload.proofRecord);
                }
                setProofState({
                    loading: proofState.loading,
                    proofs: newProofsState,
                });
            };
            agent === null || agent === void 0 ? void 0 : agent.events.on(core_1.ProofEventTypes.ProofStateChanged, listener);
            return () => {
                agent === null || agent === void 0 ? void 0 : agent.events.off(core_1.ProofEventTypes.ProofStateChanged, listener);
            };
        }
    }, [proofState, agent]);
    (0, react_1.useEffect)(() => {
        if (!basicMessageState.loading) {
            const listener = (event) => {
                const newBasicMessageState = [...basicMessageState.basicMessages];
                const index = newBasicMessageState.findIndex((basicMessage) => basicMessage.id === event.payload.basicMessageRecord.id);
                if (index > -1) {
                    newBasicMessageState[index] = event.payload.basicMessageRecord;
                }
                else {
                    newBasicMessageState.unshift(event.payload.basicMessageRecord);
                }
                setBasicMessageState({
                    loading: basicMessageState.loading,
                    basicMessages: newBasicMessageState,
                });
            };
            agent === null || agent === void 0 ? void 0 : agent.events.on(core_1.BasicMessageEventTypes.BasicMessageReceived, listener);
            return () => {
                agent === null || agent === void 0 ? void 0 : agent.events.off(core_1.BasicMessageEventTypes.BasicMessageReceived, listener);
            };
        }
    }, [basicMessageState, agent]);
    return (React.createElement(AgentContext.Provider, { value: agentState },
        React.createElement(ConnectionContext.Provider, { value: connectionState },
            React.createElement(CredentialContext.Provider, { value: credentialState },
                React.createElement(ProofContext.Provider, { value: proofState },
                    React.createElement(BasicMessageContext.Provider, { value: basicMessageState }, children))))));
};
exports.default = AgentProvider;
//# sourceMappingURL=index.js.map